##  Overview
The Managed Code section of the administration area gives you a centralized place to manage all custom code configurations. You can use it to:
  * View all custom code configurations used in automations, calculations, and webhooks.
  * Monitor execution logs to track history and resolve issues.
  * Navigate directly to the relevant feature to update or maintain your code.


Custom code runs securely within the SAP LeanIX environment.
![Screenshot of the Managed Code section showing the list of code configurations with search and filter options.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiod58993f2b4014d32a2f4702671e72eda_LowRes.png)
Managed Code Overview
